import base64
import os
class lgplib():
    def Base_64(self,PATH,IMGNAME):
        file_path = os.path.join(PATH,IMGNAME) #获取base_dir+'/image'文件夹内的文件
        f=open(file_path,'rb') #二进制方式打开图文件
        lsReadImage_f=base64.b64encode(f.read())#读取文件内容，转换为base64编码
        f.close()#关闭文件
        return "0.0.5"+str(lsReadImage_f)


#!/usr/bin/env python
from setuptools import setup, find_packages
setup( name = 'lyptest1',
       version = '0.0.1', description = 'library ', long_description = 'library ', author = 'pylyp456', author_email = '25506871@qq.com', url = 'https://github.com/ligaopan/lgp-library', license = 'MIT Licence', keywords = 'testing testautomation', platforms = 'any', python_requires = '>=3.7.*', install_requires = [], package_dir = {'': 'src'}, packages = find_packages('src') )